import logging
import os

from configparser import ConfigParser
from logging.handlers import RotatingFileHandler

def _get_level(level):
    """Internal: validate specified log level for motion alerter.
    """
    levels = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'critical': logging.CRITICAL
    }
    level = level.lower()
    if level not in levels:
        raise ValueError('{} is an invalid log level'.format(level))
    return levels[level]

def _init_logger():
    """Internal: initialize motion alerter logger.

    'maxBytes' sets the file size at which rollover begins.
    'backupCount' is the number of backups to retain.

    "The file being written to is always <app>.log. When this file is filled, it is
    closed and renamed to <app>.log.1, and if files <app>.log.1, <app>.log.2, etc.
    exist, then they are renamed to <app>.log.2, <app>.log.3 etc. respectively."
    - https://docs.python.org/3/library/logging.handlers.html#rotatingfilehandler
    """
    config = ConfigParser()
    config.read('config.ini')
    log_config = config['log']
    logger = logging.getLogger('motion_alerter')
    logger.setLevel(_get_level(log_config.get('level', 'info')))
    # create parent directory for logs if it doesn't exist
    os.makedirs(os.path.dirname(log_config['path']), exist_ok=True)
    handler = RotatingFileHandler(log_config['path'],
            maxBytes=(log_config.getint('max_size_mb', 128) * int(1e6)),
            backupCount=log_config.getint('backup_count', 10))
    handler.setFormatter(logging.Formatter(
        '%(asctime)s <%(levelname)s> - %(message)s',
        datefmt='%m/%d/%Y %H:%M:%S'))
    logger.addHandler(handler)
    return logger

log = _init_logger()
